==> filmeverwaltung-0.0.2.tar.bz2: filmeverwaltung/index.php <==
<?php
// filmeverwaltung - index.php          Copyright (C) 2009 Oliver Burger
// oliver [at] mandrivauser [dot] de    http://www.mandrivauser.de
//
// This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//


	// Abfrage der Titelvariable
 	$sortieren = $_GET["sortieren"];
	if(!isset($sortieren))
	{
		$sortieren = "index";
	}

	// beginnendes HTML-Gedöhns
	echo "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\">
	<HTML>
	<Head>
	<Title>
		CD-Register
	</Title>
	<meta http-equiv=\"Content-Type\" content=\"text/html; charset=iso-8859-1\">
	<link rel=stylesheet type=\"text/css\" href=\"./style.css\">
	</Head>
	<Body bgcolor=\"#f0f0ff\" text=\"#000044\">";

	echo "<h1>Filmesammlungs-Verwaltung</h1>
		<p>Dies ist ein php-basiertes Werkzeug zur Verwaltung Ihrer Filmesammlung.<br /></br />
		Copyright (c) 2009 Oliver Burger</p><br /><br /><br />";
	echo "&nbsp;|&nbsp; <font color=\"#cc00cc\" size=\"+1\">
		<b>&Uuml;bersicht</b></font> &nbsp;|&nbsp;
		<a href=\"./einlesen.php\">Einlesen neuer Filme</a>&nbsp;|&nbsp;
		<a href=\"./korrektur.php\">Korrektur von Eintr&auml;gen</a>&nbsp;|&nbsp<br /><br />";
	echo "Sortierung nach &nbsp;|&nbsp;
		<a href=\"./index.php?sortieren=filmname\">Filmname</a>&nbsp;|&nbsp;
		<a href=\"./index.php?sortieren=genre\">Genre</a> &nbsp;|&nbsp;<br /><br />";

	// Deklaration der benoetigten Arrays
	$raw_register = array();
	$register = array();

	// Einlesen der Datei
	$data_file = fopen("data/cd-register","r");
	while(!feof($data_file))
	{
		$zeile = fgets($data_file,1024);
		$raw_register[] = $zeile;
	}
	fclose($data_file);

	// Erstellen des Haupt-Arrays
	for($i = 0; $i < count($raw_register); $i++)
	{
		$register[$i] = explode("|",$raw_register[$i]);
	}

	// Auswahl der Unterseite
	if($sortieren == "index")
	{
		// einfach mal nix
	}
	else if($sortieren == "filmname")
	{
		// compare-Funktion zum Sortieren des zweidimensionalen Arrays
		function compare($x, $y)
		{
			if ( $x[0] == $y[0] )
			{
				if ( $x[1] == $y[1] )
					return 0;
				else if ( $x[1] < $y[1] )
					return -1;
				else
					return 1;
			}
			else if ( $x[0] < $y[0] )
				return -2;
			else
				return 2;
		}
		usort($register, 'compare');
	}
	else if($sortieren == "genre")
	{
		// compare-Funktion zum Sortieren des zweidimensionalen Arrays
		function compare($x, $y)
		{
			if ( $x[1] == $y[1] )
			{
				if ( $x[0] == $y[0] )
					return 0;
				else if ( $x[0] < $y[0] )
					return -1;
				else
					return 1;
			}
			else if ( $x[1] < $y[1] )
				return -2;
			else
				return 2;
		}
		usort($register, 'compare');
	}

	// Ausgabe der Tabelle
	echo "<table border=1 width=\"98%\" align=\"center\">
		<tr><th width=\"30%\">Titel</th>
		<th width=\"15%\">Genre</th>
		<th width=\"30%\">Schauspieler</th>
		<th width=\"10%\">CD-Case</th>
		<th width=\"15%\">Nummer</th></tr>";
	for($i=0;$i<count($register);$i++)
	{
		echo "<tr><td>".$register[$i][0]."</td>
			<td>".$register[$i][1]."</td>
			<td>".$register[$i][2]."</td>
			<td>".$register[$i][3]."</td>
			<td>".$register[$i][4]."</td></tr>";
	}
	echo "</table>";

	// abschließendes HTML-Gedöhns...
	echo "</Body>
	</HTML>";

?>

==> filmeverwaltung-0.0.2.1.tar.bz2: filmeverwaltung/index.php <==
<?php
// This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
	// Funktionen
	// compare-Funktion zum Sortieren des zweidimensionalen Arrays nach mediennummer
		function compare_mediennummer($x, $y)
		{
			if ( $x[4] == $y[4] )
			{
				$ausgabe = 0;
				if ( $x[0] == $y[0] )
					$ausgabe = 0;
				else if ( $x[0] < $y[0] )
					$ausgabe = -1;
				else
					$ausgabe = 1;
			}
			else if ( $x[4] < $y[4] )
				$ausgabe = -2;
			else
				$ausgabe = 2;
			return $ausgabe;
		}
	// compare-Funktion zum Sortieren des zweidimensionalen Arrays nach filmname
		function compare_filmname($x, $y)
		{
			$ausgabe = 0;
			if ( $x[0] == $y[0] )
			{
				if ( $x[1] == $y[1] )
					$ausgabe = 0;
				else if ( $x[1] < $y[1] )
					$ausgabe = -1;
				else
					$ausgabe = 1;
			}
			else if ( $x[0] < $y[0] )
				$ausgabe = -2;
			else
				$ausgabe = 2;
			return $ausgabe;
		}
	// compare-Funktion zum Sortieren des zweidimensionalen Arrays nach genre
		function compare_genre($x, $y)
		{
			if ( $x[1] == $y[1] )
			{
				if ( $x[0] == $y[0] )
					$ausgabe = 0;
				else if ( $x[0] < $y[0] )
					$ausgabe = -1;
				else
					$ausgabe = 1;
			}
			else if ( $x[1] < $y[1] )
				$ausgabe = -2;
			else
				$ausgabe = 2;
			return $ausgabe;
		}

	// Abfrage der Titelvariable
 	$sortieren = $_GET["sortieren"];
	if(!isset($sortieren))
	{
		$sortieren = "index";
	}

	// beginnendes HTML-Gedöhns
	echo "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\">
	<HTML>
	<Head>
	<Title>
		CD-Register
	</Title>
	<meta http-equiv=\"Content-Type\" content=\"text/html; charset=iso-8859-1\">
	<link rel=stylesheet type=\"text/css\" href=\"./style_eingabe.css\">
	</Head>
	<Body bgcolor=\"#f0f0ff\" text=\"#000044\">";

	echo "<h1>Filmesammlungs-Verwaltung</h1>
		<p>Hier haben Sie eine &Uuml;bersicht &uuml;ber Ihre Sammlung</p><br />";
	echo "&nbsp;|&nbsp; <font color=\"#cc00cc\" size=\"+1\">
		<b>&Uuml;bersicht</b></font> &nbsp;|&nbsp;
		<a href=\"./einlesen.php\">Einlesen neuer Filme</a>&nbsp;|&nbsp;
		<a href=\"./korrektur.php\">Korrektur von Eintr&auml;gen</a>&nbsp;|&nbsp<br /><br />";
	echo "Sortierung nach &nbsp;|&nbsp;
		<a href=\"./index.php\">Eingabe-Reihenfolge</a> &nbsp;|&nbsp;
		<a href=\"./index.php?sortieren=mendien_nummer\">Medien-Nummer</a> &nbsp;|&nbsp;
		<a href=\"./index.php?sortieren=filmname\">Filmname</a> &nbsp;|&nbsp;
		<a href=\"./index.php?sortieren=genre\">Genre</a> &nbsp;|&nbsp;<br /><br />";

	// Deklaration der benoetigten Arrays
	$raw_register = array();
	$register = array();

	// Einlesen der Datei
	$data_file = fopen("data/cd-register","r");
	while(!feof($data_file))
	{
		$zeile = fgets($data_file,1024);
		$raw_register[] = $zeile;
	}
	fclose($data_file);

	// Erstellen des Haupt-Arrays
	for($i = 0; $i < count($raw_register); $i++)
	{
		$register[$i] = explode("|",$raw_register[$i]);
	}

	// Auswahl der Sortierung
	if($sortieren == "index")
	{
		// einfach mal nix
	}
	else if($sortieren == "medien_nummer")
	{
		usort($register, 'compare_mediennummer');
	}
	else if($sortieren == "filmname")
	{
		usort($register, 'compare_filmname');
	}
	else if($sortieren == "genre")
	{
		usort($register, 'compare_genre');
	}

	// Ausgabe der Tabelle
	echo "<table border=1 width=\"98%\" align=\"center\">
		<tr><th width=\"30%\">Titel</th>
		<th width=\"15%\">Genre</th>
		<th width=\"30%\">Schauspieler</th>
		<th width=\"10%\">CD-Case</th>
		<th width=\"15%\">Medien-Nummer</th></tr>";
	for($i=0;$i<count($register);$i++)
	{
		echo "<tr><td>".$register[$i][0]."</td>
			<td>".$register[$i][1]."</td>
			<td>".$register[$i][2]."</td>
			<td>".$register[$i][3]."</td>
			<td>".$register[$i][4]."</td></tr>";
	}
	echo "</table>";

	// abschließendes HTML-Gedöhns...
	echo "</Body>
	</HTML>";

?>
